use dataworker::dtos::Root;
use dataworker::insert_document;
use dotenvy::dotenv;
use futures_util::StreamExt;
use sqlx::postgres::PgPoolOptions;
use std::env;
use std::error::Error;
use std::io::Write;
use tokio::fs;
use tokio::fs::DirEntry;
use tokio_stream::wrappers::ReadDirStream;

#[tokio::main]
async fn main() -> Result<(), Box<dyn Error>> {
    dotenv().ok();
    let url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
    let mut conn = PgPoolOptions::new()
        .max_connections(5)
        .connect(&url)
        .await?;

    let src = "input/xslt_dm_request";
    let total = ReadDirStream::new(fs::read_dir(src).await?).count().await;
    let mut stream = ReadDirStream::new(fs::read_dir(src).await?);
    let mut count = 0;

    while let Some(path) = stream.next().await {
        count += 1;
        let path: DirEntry = path.unwrap();
        print!(
            "\x1B[2K\r {}/{} ({})",
            count,
            total,
            path.file_name().to_str().unwrap()
        );
        std::io::stdout().flush().unwrap();
        let content = fs::read_to_string(path.path()).await.unwrap();
        if content.len() > 0 {
            if let Ok(data) = serde_json::from_str::<Root>(&content) {
                insert_document(data, &mut conn).await?;
            }
        }
    }

    println!();
    Ok(())
}
